@@ -3,18 +3,21 @@
 .. note::
     license: GNU Lesser General Public License v3.0 (see LICENSE)
 '''
-
-from __future__ import print_function
-from __future__ import unicode_literals
-from __future__ import absolute_import
+from typing import (
+    Union,
+    BinaryIO,
+    Iterable,
+    Iterator,
+    Optional,
+    Dict,
+    Callable,
+    Any,
+    List,
+    Sequence,
+)
+import sys
 
 from .account import Account
-from ..utils.compat import (
-    m3_next,
-    m3_bytes,
-    m3_is_string,
-    m3_enc,
-)
 from ..utils import (
     check_strict,
     b_left_pad,
@@ -22,11 +25,7 @@ from ..utils import (
 )
 from ..utils import messages as msg
 from ..i18n import tr as _
-from .record import (
-    RecordSequence,
-    NextMixin,
-)
-import sys
+from .record import RecordSequence
 
 
 class FileContext(object):
@@ -52,20 +51,22 @@ class File(RecordSequence):
 
     '''
 
-    def __init__(self,
-                 fd=None,
-                 **record_settings):
+    def __init__(
+        self,
+        fd: Optional[Iterable[bytes]] = None,
+        **record_settings
+    ):
         '''
         :param fd: a csb file
         :type fd: :class:`file`
 
-        :param \*\*record_settings: see :class:`csb43.csb43.RecordSequence`
+        :param **record_settings: see :class:`csb43.csb43.RecordSequence`
 
         :raises: :class:`csb43.utils.Csb43Exception`
         '''
 
-        super(File, self).__init__(**record_settings)
-        self.__accounts = []
+        super().__init__(**record_settings)
+        self.__accounts: List[Account] = []
         self.__closing = None
         self.__numRecords = 0
         self._file_context = None
@@ -77,13 +78,15 @@ class File(RecordSequence):
             def skip(record):
                 pass
 
-            launcher = {b'00': skip,
-                        b'11': self.add_account,
-                        b'22': self.add_transaction,
-                        b'23': self.add_item,
-                        b'24': self.add_exchange,
-                        b'33': self.close_account,
-                        b'88': self.close_file}
+            launcher: Dict[bytes, Callable[[bytes], None]] = {
+                b'00': skip,
+                b'11': self.add_account,
+                b'22': self.add_transaction,
+                b'23': self.add_item,
+                b'24': self.add_exchange,
+                b'33': self.close_account,
+                b'88': self.close_file
+            }
 
             for idx, line in enumerate(fd):
                 self._file_context.line = idx
@@ -103,17 +106,17 @@ class File(RecordSequence):
     # repr: [Account]
 
     @property
-    def accounts(self):
+    def accounts(self) -> Sequence[Account]:
         ":rtype: :class:`list` of accounts"
         return self.__accounts
 
-    def get_last_account(self):
+    def get_last_account(self) -> Account:
         '''
         :rtype: the last added :class:`Account`
         '''
         return self.__accounts[-1]
 
-    def add_account(self, record):
+    def add_account(self, record: Union[bytes, Account]):
         '''
         Add a new account
 
@@ -265,24 +268,24 @@ incongruente: total de registros 5 != 1
             self.__closing = ClosingFile(**settings)
             self.__closing.totalRecords = self._get_num_records()
 
-    def _get_num_records(self):
+    def _get_num_records(self) -> int:
         if self._file_context:
             return self.__numRecords
         else:
             return sum([len([x for x in ac]) for ac in self.accounts])
 
-    def is_closed(self):
+    def is_closed(self) -> bool:
         '''
         :rtype: `True` if this File has been properly closed
         '''
         return self.__closing is not None
 
     @property
-    def abstract(self):
+    def abstract(self) -> Optional['ClosingFile']:
         ":rtype: :class:`ClosingFile` file abstract"
         return self.__closing
 
-    def as_dict(self, decimal_fallback=None):
+    def as_dict(self, decimal_fallback=None) -> Dict[str, Any]:
         '''
         :param decimal_fallback: decimal number fallback representation
         :type record: :class:`bool`
@@ -319,7 +322,7 @@ incongruente: total de registros 5 != 1
             _("accounts"): [x.as_dict(decimal_fallback=decimal_fallback) for x in self.accounts]
         }
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[bytes]:
         ''':rtype: iterator of all the `CSB43` records that this object \
         represents
 
@@ -338,9 +341,13 @@ incongruente: total de registros 5 != 1
         '''
         if not self._file_context:
             self.close_file()
-        return _FileIter(self)
 
-    def __bytes__(self):
+        for account in self.accounts:
+            yield from account
+        if self.abstract:
+            yield bytes(self.abstract)
+
+    def __bytes__(self) -> bytes:
         ''':rtype: representation of this object as `CSB43` records \
         (using `\\\\n` as separator)
 
@@ -391,7 +398,7 @@ incongruente: total de registros 5 != 1
 
         template = "\n".join("* %s" % x for x in item_ac)
 
-        print(m3_enc(txt, fd), file=fd)
+        print(txt, file=fd)
 
         for ac in self.accounts:
             txt = template.format(
@@ -416,32 +423,6 @@ incongruente: total de registros 5 != 1
             print("*" * 60, file=fd)
 
 
-class _FileIter(NextMixin):
-
-    def __init__(self, f):
-        self.__output = []
-        self.__output.extend(f.accounts)
-        if f.abstract:
-            self.__output.append(f.abstract)
-
-        self.__iter = iter(self.__output)
-        self.__acc = None
-
-    def __next__(self):
-        if self.__acc:
-            try:
-                return m3_next(self.__acc)
-            except StopIteration:
-                self.__acc = None
-        now = m3_next(self.__iter)
-
-        if isinstance(now, Account):
-            self.__acc = iter(now)
-            return self.__next__()
-        else:
-            return m3_bytes(now)
-
-
 class ClosingFile(RecordSequence):
     '''
     A File abstract, given by a termination record
@@ -462,8 +443,11 @@ class ClosingFile(RecordSequence):
 
     '''
 
-    def __init__(self, record=None,
-                 **record_settings):
+    def __init__(
+        self,
+        record: Optional[bytes] = None,
+        **record_settings
+    ):
         '''
         :param record: csb record
         :type record: :class:`basestring` or `None`
@@ -473,10 +457,10 @@ class ClosingFile(RecordSequence):
 
         :raises: :class:`csb43.utils.Csb43Exception`
         '''
-        super(ClosingFile, self).__init__(**record_settings)
+        super().__init__(**record_settings)
 
-        self.__totalRecords = None
-        self.__padding = None
+        self.__totalRecords: Optional[bytes] = None
+        self.__padding: Optional[bytes] = None
 
         if record is not None:
             chk_args = self._get_check_args()
@@ -490,9 +474,11 @@ class ClosingFile(RecordSequence):
             self._set_padding(record[26:80], **chk_args)
 
     @staticmethod
-    def is_valid(record):
-        return m3_is_string(record)\
+    def is_valid(record) -> bool:
+        return (
+            isinstance(record, (str, bytes))
             and (27 <= len(record) <= 80) and (record[0:2] == b'88')
+        )
 
     # padding
     #
@@ -501,7 +487,7 @@ class ClosingFile(RecordSequence):
     # user out: bytes
 
     @check_strict(br'^.{0,54}$')
-    def _set_padding(self, value, **chk_args):
+    def _set_padding(self, value: bytes, **chk_args):
         self.__padding = value.rstrip(b" ")
 
     @property
@@ -521,7 +507,7 @@ class ClosingFile(RecordSequence):
     # user out: int
 
     @check_strict(br'^\d{6}$')
-    def _set_total_records(self, value, **chk_args):
+    def _set_total_records(self, value: bytes, **chk_args):
         self.__totalRecords = value
 
     def _get_total_records(self):
@@ -546,13 +532,15 @@ class ClosingFile(RecordSequence):
         self._set_total_records(field)
 
     @check_strict(br'^9{18}$')
-    def _check_nines(self, value, **chk_args):
+    def _check_nines(self, value: bytes, **chk_args):
         pass
 
-    def __bytes__(self):
+    def __bytes__(self) -> bytes:
         ''':rtype: representation of this object as `CSB43` records \
         (using `\\\\n` as separator)'''
-        return (b"88" +
-                b"9" * 18 +
-                b_left_pad(self._get_total_records() or b'', 6, b"0") +
-                b_right_pad(self.padding or b'', 54))
+        return (
+            b"88"
+            + b"9" * 18
+            + b_left_pad(self._get_total_records() or b'', 6, b"0")
+            + b_right_pad(self.padding or b'', 54)
+        )
